import setuptools

setuptools.setup(
    name="QtSimple6",
    version="1.0.0",
    author="XiangQinxi",
    author_email="XiangQinxi@outlook.com",
    description="",
    long_description=open("README.md", "r", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    url="https://xiangqinxidevelopment.jetbrains.space/p/tkinterdev",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
